@@ -94,6 +94,11 @@ NumericVector cpp_dfatigue(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), alpha.length(),
+                beta.length(), mu.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     alpha.length(),
@@ -129,6 +134,11 @@ NumericVector cpp_pfatigue(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), alpha.length(),
+                beta.length(), mu.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     alpha.length(),
@@ -167,6 +177,11 @@ NumericVector cpp_qfatigue(
     const bool& log_prob = false
   ) {
   
+  if (std::min({p.length(), alpha.length(),
+                beta.length(), mu.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     p.length(),
     alpha.length(),
@@ -204,6 +219,11 @@ NumericVector cpp_rfatigue(
     const NumericVector& mu
   ) {
   
+  if (std::min({alpha.length(), beta.length(), mu.length()}) < 1) {
+    Rcpp::warning("NAs produced");
+    return NumericVector(n, NA_REAL);
+  }
+  
   NumericVector x(n);
   
   bool throw_warning = false;
