@@ -33,6 +33,10 @@ NumericVector cpp_dcat(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), prob.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     static_cast<int>(x.length()),
     static_cast<int>(prob.nrow())
@@ -98,6 +102,10 @@ NumericVector cpp_pcat(
     bool lower_tail = true, bool log_prob = false
   ) {
   
+  if (std::min({x.length(), prob.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     static_cast<int>(x.length()),
     static_cast<int>(prob.nrow())
@@ -173,6 +181,10 @@ NumericVector cpp_qcat(
     const bool& log_prob = false
   ) {
   
+  if (std::min({p.length(), prob.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     static_cast<int>(p.length()),
     static_cast<int>(prob.nrow())
@@ -261,6 +273,11 @@ NumericVector cpp_rcat(
     const NumericMatrix& prob
   ) {
   
+  if (prob.length() < 1) {
+    Rcpp::warning("NAs produced");
+    return NumericVector(n, NA_REAL);
+  }
+  
   int k = prob.ncol();
   NumericVector x(n);
   int jj;
