@@ -91,6 +91,10 @@ NumericVector cpp_ddunif(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), min.length(), max.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     min.length(),
@@ -123,6 +127,10 @@ NumericVector cpp_pdunif(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), min.length(), max.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     min.length(),
@@ -158,6 +166,10 @@ NumericVector cpp_qdunif(
     const bool& log_prob = false
   ) {
   
+  if (std::min({p.length(), min.length(), max.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     p.length(),
     min.length(),
@@ -192,6 +204,11 @@ NumericVector cpp_rdunif(
     const NumericVector& max
   ) {
   
+  if (std::min({min.length(), max.length()}) < 1) {
+    Rcpp::warning("NAs produced");
+    return NumericVector(n, NA_REAL);
+  }
+  
   NumericVector x(n);
   
   bool throw_warning = false;
