@@ -62,6 +62,10 @@ NumericVector cpp_dhnorm(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), sigma.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     sigma.length()
@@ -92,6 +96,10 @@ NumericVector cpp_phnorm(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), sigma.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     sigma.length()
@@ -125,6 +133,10 @@ NumericVector cpp_qhnorm(
     const bool& log_prob = false
   ) {
   
+  if (std::min({p.length(), sigma.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     p.length(),
     sigma.length()
@@ -157,6 +169,11 @@ NumericVector cpp_rhnorm(
     const NumericVector& sigma
   ) {
   
+  if (sigma.length() < 1) {
+    Rcpp::warning("NAs produced");
+    return NumericVector(n, NA_REAL);
+  }
+  
   NumericVector x(n);
   
   bool throw_warning = false;
