@@ -21,6 +21,14 @@ NumericVector cpp_dmixpois(
     const bool& log_prob = false
   ) {
   
+  if (std::min({static_cast<int>(x.length()),
+                static_cast<int>(lambda.nrow()),
+                static_cast<int>(lambda.ncol()),
+                static_cast<int>(alpha.nrow()),
+                static_cast<int>(alpha.ncol())}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     static_cast<int>(x.length()),
     static_cast<int>(lambda.nrow()),
@@ -93,6 +101,14 @@ NumericVector cpp_pmixpois(
     const bool& log_prob = false
   ) {
   
+  if (std::min({static_cast<int>(x.length()),
+                static_cast<int>(lambda.nrow()),
+                static_cast<int>(lambda.ncol()),
+                static_cast<int>(alpha.nrow()),
+                static_cast<int>(alpha.ncol())}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     static_cast<int>(x.length()),
     static_cast<int>(lambda.nrow()),
@@ -166,6 +182,14 @@ NumericVector cpp_rmixpois(
     const NumericMatrix& alpha
   ) {
   
+  if (std::min({static_cast<int>(lambda.nrow()),
+                static_cast<int>(lambda.ncol()),
+                static_cast<int>(alpha.nrow()),
+                static_cast<int>(alpha.ncol())}) < 1) {
+    Rcpp::warning("NAs produced");
+    return NumericVector(n, NA_REAL);
+  }
+  
   int k = alpha.ncol();
   NumericVector x(n);
   
