@@ -59,6 +59,11 @@ NumericVector cpp_dnhyper(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), n.length(),
+                m.length(), r.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     n.length(),
@@ -127,6 +132,11 @@ NumericVector cpp_pnhyper(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), n.length(),
+                m.length(), r.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     n.length(),
@@ -199,6 +209,11 @@ NumericVector cpp_qnhyper(
     const bool& log_prob = false
   ) {
   
+  if (std::min({p.length(), n.length(),
+                m.length(), r.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     p.length(),
     n.length(),
@@ -270,6 +285,11 @@ NumericVector cpp_rnhyper(
     const NumericVector& r
   ) {
   
+  if (std::min({n.length(), m.length(), r.length()}) < 1) {
+    Rcpp::warning("NAs produced");
+    return NumericVector(nn, NA_REAL);
+  }
+  
   double u;
   NumericVector x(nn);
   
