@@ -105,6 +105,11 @@ NumericVector cpp_dtpois(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), lambda.length(),
+                lower.length(), upper.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     lambda.length(),
@@ -140,6 +145,11 @@ NumericVector cpp_ptpois(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), lambda.length(),
+                lower.length(), upper.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     lambda.length(),
@@ -178,6 +188,11 @@ NumericVector cpp_qtpois(
     const bool& log_prob = false
   ) {
   
+  if (std::min({p.length(), lambda.length(),
+                lower.length(), upper.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     p.length(),
     lambda.length(),
@@ -215,6 +230,11 @@ NumericVector cpp_rtpois(
     const NumericVector& upper
   ) {
   
+  if (std::min({lambda.length(), lower.length(), upper.length()}) < 1) {
+    Rcpp::warning("NAs produced");
+    return NumericVector(n, NA_REAL);
+  }
+  
   NumericVector x(n);
   
   bool throw_warning = false;
