@@ -96,6 +96,11 @@ NumericVector cpp_dzib(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), size.length(),
+                prob.length(), pi.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     size.length(),
@@ -131,6 +136,11 @@ NumericVector cpp_pzib(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), size.length(),
+                prob.length(), pi.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     size.length(),
@@ -169,6 +179,11 @@ NumericVector cpp_qzib(
     const bool& log_prob = false
   ) {
   
+  if (std::min({p.length(), size.length(),
+                prob.length(), pi.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     p.length(),
     size.length(),
@@ -206,6 +221,11 @@ NumericVector cpp_rzib(
     const NumericVector& pi
   ) {
   
+  if (std::min({size.length(), prob.length(), pi.length()}) < 1) {
+    Rcpp::warning("NAs produced");
+    return NumericVector(n, NA_REAL);
+  }
+  
   NumericVector x(n);
   
   bool throw_warning = false;
