@@ -91,6 +91,10 @@ NumericVector cpp_dzip(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), lambda.length(), pi.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     lambda.length(),
@@ -123,6 +127,10 @@ NumericVector cpp_pzip(
     const bool& log_prob = false
   ) {
   
+  if (std::min({x.length(), lambda.length(), pi.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     x.length(),
     lambda.length(),
@@ -158,6 +166,10 @@ NumericVector cpp_qzip(
     const bool& log_prob = false
   ) {
   
+  if (std::min({p.length(), lambda.length(), pi.length()}) < 1) {
+    return NumericVector(0);
+  }
+  
   int Nmax = std::max({
     p.length(),
     lambda.length(),
@@ -192,6 +204,11 @@ NumericVector cpp_rzip(
     const NumericVector& pi
   ) {
   
+  if (std::min({lambda.length(), pi.length()}) < 1) {
+    Rcpp::warning("NAs produced");
+    return NumericVector(n, NA_REAL);
+  }
+  
   NumericVector x(n);
   
   bool throw_warning = false;
